@@ -331,7 +331,7 @@ def to_date(formatted='%Y-%m-%d'):
             date = str(value.split('\n')[0])
         except:
             pass
-        if date in ('0000-00-00', '0000/00/00', '00-00-0000', '00/00/0000'):
+        if date in ('0000-00-00', '0000/00/00', '00-00-0000', '00/00/0000', ''):
             return ''
         date = datetime.strptime(date, formatted)
         return date.strftime('%Y-%m-%d')
